@@ -28,7 +28,6 @@
 #include "importwizard/importimapsettingwizard.h"
 #include "PimCommon/KActionMenuChangeCase"
 
-#include <KStandardGuiItem>
 #include <KSharedConfig>
 #include <KIconEngine>
 #include <KIconLoader>
@@ -85,6 +84,7 @@ SieveEditorMainWindow::~SieveEditorMainWindow()
 void SieveEditorMainWindow::initStatusBar()
 {
     mStatusBarInfo = new QLabel;
+    mStatusBarInfo->setTextFormat(Qt::PlainText);
     statusBar()->insertWidget(0, mStatusBarInfo, 4);
 }
 
@@ -144,7 +144,7 @@ void SieveEditorMainWindow::setupActions()
     ac->setDefaultShortcut(mNewScript, QKeySequence(Qt::CTRL + Qt::Key_N));
     mNewScript->setEnabled(false);
 
-    mEditScript =  new QAction(i18n("Edit Script..."), this);
+    mEditScript = new QAction(i18n("Edit Script..."), this);
     connect(mEditScript, &QAction::triggered, this, &SieveEditorMainWindow::slotEditScript);
     ac->addAction(QStringLiteral("edit_script"), mEditScript);
     mEditScript->setEnabled(false);
